@@ -5,7 +5,7 @@ if (!require("TH.data"))
     stop("cannot load package TH.data")
 
 ### get rid of the NAMESPACE
-attach(asNamespace("party"))
+attach(list2env(as.list(asNamespace("party"))))
 
 gtctrl <- new("GlobalTestControl")
 tlev <- levels(gtctrl@testtype)
