@@ -5,7 +5,7 @@ if (!require("MASS", quietly = TRUE))
     stop("cannot load package MASS")
 
 ### get rid of the NAMESPACE
-attach(asNamespace("party"))
+attach(list2env(as.list(asNamespace("party"))))
 
 ###
 ###
